import type { Naming, Headers } from './types';
type Params = {
    url: string;
    method?: string;
    headers?: Headers;
    body?: string;
    naming: Naming;
};
/**
 * Request Id generator.
 * Accounts for request data:
 * 1. url (protocol + host + path)
 * 2. query params (filtered with naming.query)
 * 3. method (get, post...) (as prefix)
 * 4. body, if any (filtered with naming.body)
 *
 * getRequestId does not accounts for
 * 1. blacklisted query and body params
 * 2. Any response data, including status, body and headers
 * 3. request headers (do you need that?)
 * 4. cookies
 *
 * Order agnostic, so, `/foo=bar&baz=1` will have the same rid as `/baz=1&foo=bar`
 */
declare const getRequestId: (params: Params) => string;
export default getRequestId;
